pub struct MeasuredComputeProfile {
pub identity: ComputeDeviceIdentity,
pub limits: ComputeProfileLimits,
pub samples: ComputeProfileSamples,
pub context: ComputeThermalPowerContext,
pub tile_bytes: u64,
pub allocation_bytes: Vec<u64>,
pub provenance: ComputeProfileProvenance,
pub modeled: ModeledComputeProfile,
}Expand description
Checked measured profile used by automatic routing.
Fields
identity: ComputeDeviceIdentityDevice identity.
limits: ComputeProfileLimitsProvider limits.
samples: ComputeProfileSamplesTransfer and operation sample distributions.
context: ComputeThermalPowerContextThermal and power measurement context.
tile_bytes: u64Selected tile byte size.
allocation_bytes: Vec<u64>Allocation probe byte sizes that succeeded.
provenance: ComputeProfileProvenanceProvenance for this record.
modeled: ModeledComputeProfileModeled profile to use when the evidence is accepted.
Implementations
Sourceimpl MeasuredComputeProfile
impl MeasuredComputeProfile
Sourcepub fn is_conclusive(&self) -> bool
pub fn is_conclusive(&self) -> bool
Returns true when the profile has usable, bounded measurement evidence.
Sourcepub fn is_compatible(
&self,
identity: &ComputeDeviceIdentity,
now_tick: u64,
) -> bool
pub fn is_compatible( &self, identity: &ComputeDeviceIdentity, now_tick: u64, ) -> bool
Returns true when this profile still applies to identity at now_tick.
Sourcepub fn modeled_profile(&self) -> ModeledComputeProfile
pub fn modeled_profile(&self) -> ModeledComputeProfile
Returns the modeled executor profile selected by this measured evidence.